@@ -113,13 +113,12 @@ class PackageBuild:
             'git tag -d $(git tag -l) ',  # 删除本地tag
             'git fetch',  # 拉取远程tag
             'git push origin --delete $(git tag -l)',  # 删除远程tag
-            "git tag -d $(git tag -l)",  # 删除本地tag
+            "{git tag -d $(git tag -l)}",  # 删除本地tag
             'git checkout --orphan latest_branch',  # 1.Checkout
             'git add -A',  # 2. Add all the files
             'git commit -am "clear history"',  # 3. Commit the changes
             'git branch -D master',  # 4. Delete the branch
             'git branch -m master',  # 5.Rename the current branch to master
-            'git pull -v origin',
             'git push -f origin master',  # 6.Finally, force update your repository
             'git push --set-upstream origin master',
         ])
